==> wevue-2.1.4.tgz: package/vue2/@wevue-tools/src/filters/page-data-methods-filter.js <==
let config = require('../../json')

let vueExtendRegex = /^\$\$/

function getComputedList() {
    let ret = {}
    if (__WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH]) {
        if (__WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH].data) {
            ret = __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH].data
        }
        for(let i in __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH]){
            if((!i.match(vueExtendRegex))&&typeof __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH][i] !=='function'&&i!=='data'){
                ret[i] = new Object()
                ret[i] = __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH][i]
            }
        }
    }
    return ret
}


function getMethodsList() {
    let reservedPageFunctionNameList = config.reservedPageFunctionName||[]
    let ret = {}
    if (__WEVUE_GI.PageXCXOpt) {
        for(let i in __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH]){
            if((!i.match(vueExtendRegex))&&typeof __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH][i] ==='function'&&reservedPageFunctionNameList.indexOf(i)===-1){
                ret[i] = new Function()
                ret[i] = __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH][i]
            }
        }
    }
    return ret
}

/**
 * @lzq
 * 获取vue配置拓展
 */
function getVueExtendList(){
    let reservedPageVueExtendNameList = config.reservedPageVueExtendName||[]
    let ret = {}
    if (__WEVUE_GI.PageXCXOpt) {
        for(let i in __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH]){
            if((!!i.match(vueExtendRegex))&&reservedPageVueExtendNameList.indexOf(i)===-1){
                ret[i.replace(vueExtendRegex,'')] = new Object()
                ret[i.replace(vueExtendRegex,'')] = __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH][i]
            }
        }
    }
    return ret
}
/**
 * @lzq
 * computed and methods list
 */
export function pageFilter() {
    let computedList = getComputedList()
    let methodsList = getMethodsList()
    let vueExtendList = getVueExtendList()
    let ret = {
        data: computedList,
        methods: methodsList,
        vueAttr:vueExtendList
    }

    return ret
}

==> wevue-2.2.5.tgz: package/vue2/@wevue-tools/src/filters/page-data-methods-filter.js <==
let config = require('../../json')

let vueExtendRegex = /^\$\$/

function getComputedList(config) {
    let ret = {}
    if (__WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH]) {
        if (__WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH].data) {
            ret = __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH].data
        }
        for(let i in __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH]){
            if((!i.match(vueExtendRegex))&&typeof __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH][i] !=='function'&&i!=='data'){
                ret[i] = new Object()
                ret[i] = __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH][i]
            }
        }
    }
    return ret
}


function getMethodsList(config) {
    let reservedPageFunctionNameList = config.reservedPageFunctionName||[]
    let ret = {}
    if (__WEVUE_GI.PageXCXOpt) {
        for(let i in __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH]){
            if((!i.match(vueExtendRegex))&&typeof __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH][i] ==='function'&&reservedPageFunctionNameList.indexOf(i)===-1){
                ret[i] = new Function()
                ret[i] = __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH][i]
            }
        }
    }
    return ret
}

/**
 * @lzq
 * 获取vue配置拓展
 */
function getVueExtendList(config){
    let reservedPageVueExtendNameList = config.reservedPageVueExtendName||[]
    let ret = {}
    if (__WEVUE_GI.PageXCXOpt) {
        for(let i in __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH]){
            if((!!i.match(vueExtendRegex))&&reservedPageVueExtendNameList.indexOf(i)===-1){
                ret[i.replace(vueExtendRegex,'')] = new Object()
                ret[i.replace(vueExtendRegex,'')] = __WEVUE_GI.PageXCXOpt[__WEVUE_GI.PAGEPATH][i]
            }
        }
    }
    return ret
}
/**
 * @lzq
 * computed and methods list
 */
export function pageFilter(config) {
    let computedList = getComputedList(config)
    let methodsList = getMethodsList(config)
    let vueExtendList = getVueExtendList(config)
    let ret = {
        data: computedList,
        methods: methodsList,
        vueAttr:vueExtendList
    }

    return ret
}
